/* This work is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License. */

package com.thetwo.accessibilityfocus;

import java.io.InputStream;
import java.net.URL;
import java.lang.Exception;

import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.ColorDrawable;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.accessibility.AccessibilityEvent;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;
import android.view.View.OnClickListener;
import android.view.View.OnLongClickListener;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.events.RCTEventEmitter;

/**
 * Created by nicokant on 15/03/18.
 */

class DownloadImageTask extends AsyncTask<String, Void, Bitmap> {
    ImageView bmImage;
    public DownloadImageTask(ImageView bmImage) {
        this.bmImage = bmImage;
    }

    protected Bitmap doInBackground(String... urls) {
        String urldisplay = urls[0];
        Bitmap mIcon11 = null;
        try {
            InputStream in = new java.net.URL(urldisplay).openStream();
            mIcon11 = BitmapFactory.decodeStream(in);
        } catch (Exception e) {
            Log.e("Error", e.getMessage());
            e.printStackTrace();
        }
        return mIcon11;
    }

    protected void onPostExecute(Bitmap result) {
        bmImage.setImageBitmap(result);
    }
}

public class RNAccessibilityFocusLayout extends FrameLayout implements OnClickListener, OnLongClickListener {
    ImageView image;

    public RNAccessibilityFocusLayout(ThemedReactContext context) {
        super(context);
        image = new ImageView(context);
        image.setLayoutParams(new LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        this.addView(image);
        image.setFocusable(true);
        image.setImportantForAccessibility(1);
        image.setOnClickListener(this);
        image.setOnLongClickListener(this);
        this.setFocusable(false);
        installAccessibilityDelegate();
    }

    public void onClick(View v) {
        this.sendReactNativeEvent("click");
    }

    public boolean onLongClick(View v) {
        this.sendReactNativeEvent("long_click");
        return true;
    }

    public void installAccessibilityDelegate() {
        setAccessibilityDelegate(new AccessibilityDelegate() {
            @Override
            public boolean onRequestSendAccessibilityEvent(ViewGroup viewGroup, View child, AccessibilityEvent event) {
                if (event.getEventType() == AccessibilityEvent.TYPE_VIEW_ACCESSIBILITY_FOCUSED) {
                    sendReactNativeEvent("start");
                    return false;
                }

                if (event.getEventType() == AccessibilityEvent.TYPE_VIEW_ACCESSIBILITY_FOCUS_CLEARED) {
                    sendReactNativeEvent("end");
                    return false;
                }

                return super.onRequestSendAccessibilityEvent(viewGroup, child, event);
            }
        });
    }

    public void setImage(String identifier) {
        if (identifier.startsWith("http://") || identifier.startsWith("https://")) {
            new DownloadImageTask(image).execute(identifier);
        } else {
            int resourceId = getContext().getResources().getIdentifier(identifier, "drawable", getContext().getPackageName());
            image.setImageResource(resourceId);
        }
    }

    public void setLabel(String label) {
        image.setContentDescription(label);
    }

    private void sendReactNativeEvent(String type) {
        WritableMap event = Arguments.createMap();
        ReactContext reactContext = (ReactContext) getContext();
        reactContext.getJSModule(RCTEventEmitter.class).receiveEvent(
                getId(),
                "native_accessibility_focus_" + type,
                event
        );
    }
}
