/* This work is licensed under a Creative Commons Attribution-NonCommercial 4.0 International License. */

package com.thetwo.accessibilityfocus;

import java.util.Map;

import com.facebook.react.uimanager.ViewGroupManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.annotations.ReactProp;

import javax.annotation.Nullable;

public class RNAccessibilityFocusManager extends ViewGroupManager<RNAccessibilityFocusLayout> {
    public static final String REACT_CLASS = "AccessibilityFocus";

    @Override
    public String getName() {
        return REACT_CLASS;
    }

    @ReactProp(name = "src")
    public void setSrc(RNAccessibilityFocusLayout view, @Nullable String filename) {
        view.setImage(filename);
    }

    @ReactProp(name = "label")
    public void setLabel(RNAccessibilityFocusLayout view, @Nullable String label) {
        view.setLabel(label);
    }

    @Override
    protected RNAccessibilityFocusLayout createViewInstance(ThemedReactContext reactContext) {
        return new RNAccessibilityFocusLayout(reactContext);
    }

    public Map getExportedCustomBubblingEventTypeConstants() {
        return MapBuilder.builder()
                .put(
                        "native_accessibility_focus_start",
                        MapBuilder.of(
                                "phasedRegistrationNames",
                                MapBuilder.of("bubbled", "onAccessibilityFocusStart")))
                .put(
                        "native_accessibility_focus_end",
                        MapBuilder.of(
                                "phasedRegistrationNames",
                                MapBuilder.of("bubbled", "onAccessibilityFocusEnd")))
                .put(
                        "native_accessibility_focus_click",
                        MapBuilder.of(
                            "phasedRegistrationNames",
                            MapBuilder.of("bubbled", "onPress")))
                .put(
                    "native_accessibility_focus_long_click",
                    MapBuilder.of(
                        "phasedRegistrationNames",
                        MapBuilder.of("bubbled", "onLongPress")))
                .build();
    }
}
